@@ -34,6 +34,7 @@ Main code for opsgeniecli
 from datetime import timedelta
 from datetime import datetime
 from operator import itemgetter
+import pendulum
 import urllib.parse
 import urllib.request
 import os
@@ -555,8 +556,9 @@ def policy_alerts_disable(context, team_id, filter_, id_, team_name):  # pylint:
 @click.option('--team-id', 'team_id', cls=MutuallyExclusiveOption, mutually_exclusive=["team_name"],
               help='Specify the team id for team-based alert policies instead of global policies.')
 @click.option('--team-name', 'team_name', default=False, cls=MutuallyExclusiveOption, mutually_exclusive=["team_id"])
+@click.option('--active', 'enabled', default=False, is_flag=True)
 @click.pass_context
-def policy_alerts_list(context, team_id, team_name, print_output=True):
+def policy_alerts_list(context, team_id, team_name, enabled, print_output=True):
     """
     Function to list alert policies
 
@@ -578,8 +580,13 @@ def policy_alerts_list(context, team_id, team_name, print_output=True):
         )
     result = context.obj['opsgenie'].list_alert_policy(team_id)
     format_table = PrettyTable(['teamid', 'name', 'enabled'])
-    for item in result['data']:
-        format_table.add_row([item['id'], item['name'], item['enabled']])
+    sortedlist = sorted(result['data'], key=itemgetter('name'))
+    for item in sortedlist:
+        if enabled:
+            if item['enabled']:
+                format_table.add_row([item['id'], item['name'], item['enabled']])
+        else:
+            format_table.add_row([item['id'], item['name'], item['enabled']])
     if print_output:
         print(format_table)
         return None
@@ -1160,12 +1167,17 @@ def policy_maintenance_list(context, nonexpired, past):
         result = context.obj['opsgenie'].list_maintenance(past=True)
     else:
         result = context.obj['opsgenie'].list_maintenance()
-    format_table = PrettyTable(['id', 'status', 'description', 'type', 'startdate'])
+    format_table = PrettyTable(['id', 'status', 'description', 'type', 'startdate', 'enddate'])
     for item in result['data']:
+        if item['time']['endDate']:
+            truncated_end_date = (item['time']['endDate'].replace('Z', '')).split(".")[0]
+            modified_end_date = datetime.fromisoformat(truncated_end_date).strftime('%Y-%m-%d %H:%M:%S')
+        else:
+            item['time']['endDate'] = None
         truncated_start_date = (item['time']['startDate'].replace('Z', '')).split(".")[0]
-        modified_format = datetime.fromisoformat(truncated_start_date).strftime('%Y-%m-%d %H:%M:%S')
+        modified_start_date = datetime.fromisoformat(truncated_start_date).strftime('%Y-%m-%d %H:%M:%S')
         format_table.add_row([item['id'], item['status'], item['description'],
-                              item['time']['type'], modified_format])
+                              item['time']['type'], modified_start_date, modified_end_date])
     print(format_table)
 
 
@@ -1610,7 +1622,7 @@ def schedules_timeline(context, team_name, start_date, end_date, exclude_enginee
     for item in result['data'][f'finalTimeline']['rotations'][0]['periods']:
         item_date_value = datetime.strptime((item['startDate'].replace('Z', '')).split(".")[0], "%Y-%m-%dT%H:%M:%S").date()
         if start_date <= item_date_value and item_date_value < end_date:
-            all_start_dates += [item['startDate'].split("Z")[0]]
+            all_start_dates += [(item['startDate'].replace('Z', '')).split(".")[0]]
             time_zone = pytz.timezone("UTC")
 
             start_dt_truncated = (item['startDate'].replace('Z', '')).split(".")[0]
@@ -1639,13 +1651,12 @@ def schedules_timeline(context, team_name, start_date, end_date, exclude_enginee
             if engineer != last_engineer:
                 break
 
-        end_date_x = str((datetime.strptime(date, "%Y-%m-%dT%H:%M:%S").date() + timedelta(days=1)))
-
         start_utc_dt = time_zone.localize((datetime.fromisoformat(date)))
         start_ams_dt = (start_utc_dt.astimezone(pytz.timezone("Europe/Amsterdam"))).strftime('%Y-%m-%d %H:%M:%S')
 
+        end_date_x = str((datetime.strptime(date, "%Y-%m-%dT%H:%M:%S").date() + timedelta(days=1)))
         stop_utc_dt = time_zone.localize((datetime.fromisoformat(end_date_x)))
-        stop_ams_dt = (start_utc_dt.astimezone(pytz.timezone("Europe/Amsterdam"))).strftime('%Y-%m-%d %H:%M:%S')
+        stop_ams_dt = (stop_utc_dt.astimezone(pytz.timezone("Europe/Amsterdam"))).strftime('%Y-%m-%d %H:%M:%S')
 
         format_table.add_row([engineer, start_ams_dt, stop_ams_dt])
         last_engineer = format_table._rows[-1][0]
@@ -2026,9 +2037,9 @@ def on_call(context):
 
 @bootstrapper.command(cls=DefaultHelp, name='override')
 @click.option('--start-date', 'start_date', cls=MutuallyExclusiveOption, mutually_exclusive=["hours"],
-              help='Example: 2019-03-15T14:34:09Z.')
+              help='Example: 2019-03-15T14:34:09.')
 @click.option('--end-date', 'end_date', cls=MutuallyExclusiveOption, mutually_exclusive=["hours"],
-              help='Example: 2019-03-15T15:34:09Z')
+              help='Example: 2019-03-15T15:34:09')
 @click.option('--team-name', 'team_name')
 @click.option('--engineer', help='Name the username of the engineer who will be on call.')
 @click.option('--hours', type=int, help='Amount of hours to set the override for.')
@@ -2050,28 +2061,28 @@ def override(context, team_name, engineer, hours, start_date, end_date):  # pyli
     Examples:
     $ opsgeniecli.py override --team_name <TEAMSCHEDULE> --engineer <ENGINEER> --hours <INTEGER>
     $ opsgeniecli.py override --team_name <TEAMSCHEDULE> --engineer <ENGINEER>
-    --start_date 2019-03-15T14:34:09Z --end_date 2019-03-15T15:34:09Z
+    --start_date 2019-03-15T14:34:09 --end_date 2019-03-15T15:34:09
 
     """
     if team_name:
         team_name = find_team_schedule_name_by_name(team_name)  # pylint: disable=no-value-for-parameter
     if hours:
         result = context.obj['opsgenie'].set_override_for_hours(team_name, engineer, hours)
-        output_start_date = datetime.now().strftime('%Y-%m-%d %H:%M:%S')
-        output_end_date = (datetime.now() + timedelta(hours=hours)).strftime('%Y-%m-%d %H:%M:%S')
+        start_dt = pendulum.now(tz='Europe/Amsterdam')
+        end_dt = start_dt.add(hours=hours)
     elif start_date and end_date:
-        result = context.obj['opsgenie'].set_override_scheduled(team_name, start_date, end_date, engineer)
-        start = datetime.strptime(start_date, "%Y-%m-%dT%H:%M:%SZ")
-        end = datetime.strptime(end_date, "%Y-%m-%dT%H:%M:%SZ")
-        output_start_date = start.astimezone(pytz.utc).strftime('%Y-%m-%d %H:%M:%S')
-        output_end_date = end.astimezone(pytz.utc).strftime('%Y-%m-%d %H:%M:%S')
+        start_dt = pendulum.parse(start_date, tz='Europe/Amsterdam')
+        start_dt_utc = start_dt.in_tz('UTC').format('YYYY-MM-DDTHH:MM:SSZ')
+        end_dt = pendulum.parse(end_date, tz='Europe/Amsterdam')
+        end_dt_utc = start_dt.in_tz('UTC').format('YYYY-MM-DDTHH:MM:SSZ')
+        result = context.obj['opsgenie'].set_override_scheduled(team_name, start_dt_utc, end_dt_utc, engineer)
     else:
         raise click.UsageError(
             "Specify the amount of hours you want to override the schedule (using --hours), \
             or specify a schedule (using --start_date and --end_date)."
         )
     if result.status_code == 201:
-        print(f"✓ - override set to {engineer} between {output_start_date} and {output_end_date}")
+        print(f"✓ - override set to {engineer} between {start_dt.to_datetime_string()} and {end_dt.to_datetime_string()}")
     else:
         print(result.text)
 
